#[non_exhaustive]pub enum DocumentError {
UnterminatedFrontmatter,
FrontmatterNotMapping,
InvalidYaml(YamlError),
MissingKeys(Vec<String>),
InvalidConceptId(ConceptIdError),
}Expand description
Errors raised when parsing or validating a single OKF concept document.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnterminatedFrontmatter
The frontmatter opened with --- but no closing --- was found.
FrontmatterNotMapping
The frontmatter block did not contain a YAML mapping.
InvalidYaml(YamlError)
The YAML frontmatter could not be parsed.
MissingKeys(Vec<String>)
Required frontmatter keys are missing or empty.
InvalidConceptId(ConceptIdError)
The file’s path could not be turned into a valid concept id.