Module error

Module error 

Error types for the crate.

Enums

BundleError
Errors raised when loading or operating on a bundle on disk.
DocumentError
Errors raised when parsing or validating a single OKF concept document.