remove_concept

Function remove_concept 

pub fn remove_concept(
    bundle: &Bundle,
    target: &ConceptId,
    options: &RemoveOptions,
) -> Result<RemoveReport, RefactorError>
Safely removes a concept from the bundle.

Errors

Returns RefactorError::ConceptNotFound if target is not in the bundle, RefactorError::HasInboundLinks if other concepts link to target and force/redirect_to/unlink were not given, or RefactorError::Io on filesystem error.