pub enum ResourceKind {
Url,
Path,
Scope,
Missing,
}Expand description
What kind of thing a sources[].resource names.
Variants
Url
An absolute URL.
Path
A path a consumer can follow into the bundle (or a references/ file).
Scope
A population or scope descriptor a consumer cannot follow, such as
all queries in BigQuery project X.
Missing
No resource was given, so the entry is malformed, since resource is
REQUIRED within an entry.