pub fn split_concept(
bundle: &Bundle,
source: &ConceptId,
target: &ConceptId,
options: &SplitOptions,
) -> Result<SplitReport, RefactorError>Expand description
Splits a section from an existing concept into a new concept.
Errors
Returns RefactorError::SameSourceAndTarget if source equals target,
RefactorError::ConceptNotFound if source is not found,
RefactorError::ConceptAlreadyExists if target exists and force is false,
RefactorError::SectionNotFound if the section is not found in source, or
RefactorError::Io on filesystem error.