pub struct FrontmatterChange {
pub id: ConceptId,
pub added: Vec<String>,
pub removed: Vec<String>,
pub changed: Vec<(String, String, String)>,
}Expand description
Frontmatter key changes for a concept present in both bundles.
Fields
id: ConceptIdThe concept the change applies to.
added: Vec<String>Keys present in the second bundle but not the first.
removed: Vec<String>Keys present in the first bundle but not the second.
changed: Vec<(String, String, String)>Keys present in both but with a different value, as
(key, old display form, new display form).