Module error
okf_
core
0.2.5
Module error
Module Items
Enums
In crate okf_
core
okf_core
Module
error
Error types for the crate.
Enums

Bundle
Error
Errors raised when loading or operating on a bundle on disk.
Document
Error
Errors raised when parsing or validating a single OKF concept document.