pub struct BundleFixReport {
pub bundle_root: PathBuf,
pub files: Vec<FileFixReport>,
pub index_files_to_regenerate: Vec<PathBuf>,
pub options: FixOptions,
}Expand description
Remediation report for a whole bundle.
Fields
bundle_root: PathBufBundle root directory.
files: Vec<FileFixReport>Reports for individual files.
index_files_to_regenerate: Vec<PathBuf>Index files that are out of sync or would be regenerated.
options: FixOptionsOptions used.
Implementations
Sourceimpl BundleFixReport
impl BundleFixReport
Sourcepub fn total_remediations(&self) -> usize
pub fn total_remediations(&self) -> usize
Total number of remediation actions applied across all files.
Sourcepub fn changed_files(&self) -> impl Iterator<Item = &FileFixReport>
pub fn changed_files(&self) -> impl Iterator<Item = &FileFixReport>
All files that were or would be modified.