pub struct Mapping { /* private fields */ }Expand description
Implementations
Sourceimpl Mapping
impl Mapping
Sourcepub fn get_mut(&mut self, key: &str) -> Option<&mut Value>
pub fn get_mut(&mut self, key: &str) -> Option<&mut Value>
Looks up a mutable value by string key.
Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Returns true if the mapping contains the given string key.
Sourcepub fn insert(&mut self, key: impl Into<String>, value: Value) -> Option<Value>
pub fn insert(&mut self, key: impl Into<String>, value: Value) -> Option<Value>
Inserts (or, if the string key already exists, replaces) a value, preserving the position of an existing key. Returns the previous value.
Sourcepub fn remove(&mut self, key: &str) -> Option<Value>
pub fn remove(&mut self, key: &str) -> Option<Value>
Removes a value by string key, preserving order of the rest.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&Value, &Value)>
pub fn iter(&self) -> impl Iterator<Item = (&Value, &Value)>
Iterates over (key, value) pairs in order.
Sourcepub fn iter_mut(&mut self) -> impl Iterator<Item = (&mut Value, &mut Value)>
pub fn iter_mut(&mut self) -> impl Iterator<Item = (&mut Value, &mut Value)>
Iterates over mutable (key, value) pairs in order.